==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/TreemapNodeStylingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TreemapNodeStyleDescriptionMetadata } from "./TreemapNodeStyleDescriptionMetadata";
import { TreemapNodeStylingEventArgsDescription } from "./TreemapNodeStylingEventArgsDescription";
/**
 * @hidden
 */
var TreemapNodeStylingEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(TreemapNodeStylingEventArgsDescriptionMetadata, _super);
    function TreemapNodeStylingEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TreemapNodeStylingEventArgsDescriptionMetadata.b = function (a) {
        if (TreemapNodeStylingEventArgsDescriptionMetadata.a == null) {
            TreemapNodeStylingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TreemapNodeStylingEventArgsDescriptionMetadata.c(TreemapNodeStylingEventArgsDescriptionMetadata.a);
        }
        if (a.j(TreemapNodeStylingEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(TreemapNodeStylingEventArgsDescriptionMetadata.a);
        TreemapNodeStyleDescriptionMetadata.d(a);
    };
    TreemapNodeStylingEventArgsDescriptionMetadata.c = function (a) {
        a.item("Value", "Number:double");
        a.item("Sum", "Number:double");
        a.item("CustomValueRef", "(w:CustomValue,wf:CustomValue)DataRef");
        a.item("ItemRef", "(w:Item,wf:Item)DataRef");
        a.item("ParentItemRef", "(w:ParentItem,wf:ParentItem)DataRef");
        a.item("Label", "String");
        a.item("ParentValue", "Number:double");
        a.item("ParentLabel", "String");
        a.item("ParentSum", "Number:double");
        a.item("IsParent", "Boolean");
        a.item("Style", "ExportedType:TreemapNodeStyle");
    };
    TreemapNodeStylingEventArgsDescriptionMetadata.d = function (a) {
        TreemapNodeStylingEventArgsDescriptionMetadata.b(a);
        a.aa("TreemapNodeStylingEventArgs", function () { return new TreemapNodeStylingEventArgsDescription(); });
        a.z("TreemapNodeStylingEventArgs", TreemapNodeStylingEventArgsDescriptionMetadata.a);
    };
    TreemapNodeStylingEventArgsDescriptionMetadata.$t = markType(TreemapNodeStylingEventArgsDescriptionMetadata, 'TreemapNodeStylingEventArgsDescriptionMetadata');
    TreemapNodeStylingEventArgsDescriptionMetadata.a = null;
    return TreemapNodeStylingEventArgsDescriptionMetadata;
}(Base));
export { TreemapNodeStylingEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/TreemapNodeStylingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TreemapNodeStyleDescriptionMetadata } from "./TreemapNodeStyleDescriptionMetadata";
import { TreemapNodeStylingEventArgsDescription } from "./TreemapNodeStylingEventArgsDescription";
/**
 * @hidden
 */
var TreemapNodeStylingEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(TreemapNodeStylingEventArgsDescriptionMetadata, _super);
    function TreemapNodeStylingEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TreemapNodeStylingEventArgsDescriptionMetadata.b = function (a) {
        if (TreemapNodeStylingEventArgsDescriptionMetadata.a == null) {
            TreemapNodeStylingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TreemapNodeStylingEventArgsDescriptionMetadata.c(TreemapNodeStylingEventArgsDescriptionMetadata.a);
        }
        if (a.k(TreemapNodeStylingEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(TreemapNodeStylingEventArgsDescriptionMetadata.a);
        TreemapNodeStyleDescriptionMetadata.d(a);
    };
    TreemapNodeStylingEventArgsDescriptionMetadata.c = function (a) {
        a.item("Value", "Number:double");
        a.item("Sum", "Number:double");
        a.item("CustomValueRef", "(w:CustomValue,wf:CustomValue)DataRef");
        a.item("ItemRef", "(w:Item,wf:Item)DataRef");
        a.item("ParentItemRef", "(w:ParentItem,wf:ParentItem)DataRef");
        a.item("Label", "String");
        a.item("ParentValue", "Number:double");
        a.item("ParentLabel", "String");
        a.item("ParentSum", "Number:double");
        a.item("IsParent", "Boolean");
        a.item("Style", "ExportedType:TreemapNodeStyle");
    };
    TreemapNodeStylingEventArgsDescriptionMetadata.d = function (a) {
        TreemapNodeStylingEventArgsDescriptionMetadata.b(a);
        a.ac("TreemapNodeStylingEventArgs", function () { return new TreemapNodeStylingEventArgsDescription(); });
        a.ab("TreemapNodeStylingEventArgs", TreemapNodeStylingEventArgsDescriptionMetadata.a);
    };
    TreemapNodeStylingEventArgsDescriptionMetadata.$t = markType(TreemapNodeStylingEventArgsDescriptionMetadata, 'TreemapNodeStylingEventArgsDescriptionMetadata');
    TreemapNodeStylingEventArgsDescriptionMetadata.a = null;
    return TreemapNodeStylingEventArgsDescriptionMetadata;
}(Base));
export { TreemapNodeStylingEventArgsDescriptionMetadata };
